@@ -602,8 +602,15 @@ class ContinuumNormalizationMatch(ContinuumNormalizationAbstract):
 
         # TODO: what should this be?
         if self.top_factor != 0:
+            from scipy.ndimage import median_filter
+
+            diff = median_filter(y, 5) - y
+            std = 1.5 * np.median(np.abs(diff[diff != 0] - np.median(diff[diff != 0])))
+            snr = 1 / std
+            factor = 1000 + (snr - 50) * 90
+            factor = np.clip(factor, 100, 100_000)
             mod = np.nanmedian(u) / np.nanmedian(y) * (np.nanpercentile(y, 95) - y) ** 2
-            u = u + self.top_factor * mod
+            u = u + factor * mod
 
         deg = sme.cscale_degree
         p0 = sme.cscale[segments]
@@ -971,10 +978,10 @@ def determine_radial_velocity(
 
         # Filter the mask for the correct sections
         # Need to use temporary m instead of mask, so that we can check
-        m = (mask & MASK_VALUES.VRAD) != 0
+        m = mask == MASK_VALUES.VRAD
         if not np.any(m):
             # No VRAD specified, use LINE instead
-            m = (mask & MASK_VALUES.LINE) != 0
+            m = mask == MASK_VALUES.LINE
         mask = m
         mask &= u_obs != 0
 
