@@ -25,8 +25,7 @@ from . import __version__ as smeversion
 from .sme_synth import SME_DLL
 
 logger = logging.getLogger(__name__)
-show_progress_bars = True
-
+show_progress_bars = False
 
 def disable_progress_bars():
     global show_progress_bars
